==> ejc-sale-api-3.0.0-20220929.071506-226-sources.jar: com.ejianc.business.sale/salesorder/vo/NetweightSumVO.java <==
package com.ejianc.business.sale.salesorder.vo;

import com.fasterxml.jackson.annotation.JsonFormat;

import javax.xml.crypto.Data;
import java.math.BigDecimal;

/**
 * @authoer:禹鹏杰
 * @createDate:2022/9/18
 * @description:
 */
public class NetweightSumVO {
    private Long productId; // 产品主键
    private String productName; // 产品名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Data shipDates; // 发货日期年月日
    private BigDecimal netWeightSum; // 净重
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public Data getShipDates() {
        return shipDates;
    }

    public void setShipDates(Data shipDates) {
        this.shipDates = shipDates;
    }

    public BigDecimal getNetWeightSum() {
        return netWeightSum;
    }

    public void setNetWeightSum(BigDecimal netWeightSum) {
        this.netWeightSum = netWeightSum;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
}

==> ejc-sale-api-3.0.0-20220929.072420-227-sources.jar: com.ejianc.business.sale/salesorder/vo/NetweightSumVO.java <==
package com.ejianc.business.sale.salesorder.vo;

import com.fasterxml.jackson.annotation.JsonFormat;

import javax.xml.crypto.Data;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @authoer:禹鹏杰
 * @createDate:2022/9/18
 * @description:
 */
public class NetweightSumVO {
    private Long productId; // 产品主键
    private String productName; // 产品名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date shipDates; // 发货日期年月日
    private BigDecimal netWeightSum; // 净重
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public Date getShipDates() {
        return shipDates;
    }

    public void setShipDates(Date shipDates) {
        this.shipDates = shipDates;
    }

    public BigDecimal getNetWeightSum() {
        return netWeightSum;
    }

    public void setNetWeightSum(BigDecimal netWeightSum) {
        this.netWeightSum = netWeightSum;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
}
